popper/popper.c | 16 ++++++++--------
1 files changed, 8 insertions(+), 8 deletions(-)
diff --git a/popper/popper.c b/popper/popper.c
index 722c3a1..9b6499c 100644
--- a/popper/popper.c
+++ b/popper/popper.c
@@ -146,7 +146,7 @@ char ** argv;
char message [ MAXLINELEN ];
pop_result rslt = POP_FAILURE;
char * tgetline();
- char * getline();
+ char * getline2();
/*
* seed random with the current time to nearest second
@@ -411,7 +411,7 @@ jmp_buf env;
/*
* Our own getline. One reason we don't use fgets because there was
* a comment here that fgets was broken on AIX. Another reason is
* that we need to read out of the TLS stream at times.
*
@@ -421,7 +421,7 @@ jmp_buf env;
*/
char
*getline ( char *str, int size, POP *pPOP )
{
char *p = NULL;
int nRead = 0;
@@ -429,7 +429,7 @@ char
int nBufSz = sizeof ( pPOP->pcInBuf );
- _DEBUG_LOG2 ( pPOP, "getline(%p,%d)", str, size );
+ _DEBUG_LOG2 ( pPOP, "getline2(%p,%d)", str, size );
/*
* See if there's a line in our input buffer
@@ -468,7 +468,7 @@ char
pPOP->pcInStart - pPOP->pcInBuf );
pPOP->pcInStart = pPOP->pcInEnd = pPOP->pcInBuf;
}
- _DEBUG_LOG3 ( pPOP, "getline() returning %d: '%.*s'",
+ _DEBUG_LOG3 ( pPOP, "getline2() returning %d: '%.*s'",
strlen(str), MIN(25, (int) strlen(str)), str );
return ( str );
} /* got a line */
@@ -556,7 +556,7 @@ char
} /* found a '\n' */
} /* loop and discard until we see a '\n' */
- _DEBUG_LOG2 ( pPOP, "getline() returning %d ('%c')",
+ _DEBUG_LOG2 ( pPOP, "getline2() returning %d ('%c')",
strlen(str), *str );
return ( str );
} /* nRoom == 0 */
@@ -579,7 +579,7 @@ char
break;
} /* main loop */
- _DEBUG_LOG0 ( pPOP, "getline() returning NULL" );
+ _DEBUG_LOG0 ( pPOP, "getline2() returning NULL" );
return ( NULL );
}
@@ -610,7 +610,7 @@ tgetline ( char *str, int size, POP *p, int timeout )
VERSION, timeout, p->user, p->client, p->ipaddr );
}
else
- str = getline ( str, size, p );
+ str = getline2 ( str, size, p );
alarm ( 0 );
signal ( SIGALRM, SIG_DFL );
@@ -411,7 +411,7 @@ jmp_buf env;
/*
- * Our own getline. One reason we don't use fgets because there was
+ * Our own getline2. One reason we don't use fgets because there was
* a comment here that fgets was broken on AIX. Another reason is
* that we need to read out of the TLS stream at times.
@@ -421,7 +421,7 @@ jmp_buf env;
*/
char
-*getline ( char *str, int size, POP *pPOP )
+*getline2 ( char *str, int size, POP *pPOP )
{
char *p = NULL;